/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.scripting.jruby.monitor;

import com.sun.grizzly.tcp.http11.GrizzlyRequest;
import com.sun.grizzly.tcp.http11.GrizzlyResponse;

/**
 * @author Vivek Pandey
 */
public interface JRubyMonitorListner {

    /**
     * Monitoring stat for the JRuby application at start.
     *
     * @param appName         Name of the application
     * @param appType Could be Rails, Merb, Sinatra or User Defined
     * @param environment     development, production or test or maybe what user mentioned
     *                        as part of jruby.environment setting
     * @param jrubyVersion    JRuby Version
     */
    void started(String appName, String appType, String environment, String jrubyVersion);

    /**
     * Monitoring stat for the JRuby application at the end.
     *
     * @param appName         Name of the application
     * @param appType Could be Rails, Merb, Sinatra or User Defined
     * @param environment     development, production or test or maybe what user mentioned
     *                        as part of jruby.environment setting
     */
    void stopped(String appName, String appType, String environment);

    /**
     * JRuby runtime pool stats at the start.
     *
     * @param hardMinimum        Minimum runtimes active
     * @param hardMaximum        Maximum runtimes active
     * @param activeRuntimes     Currently active runtimes
     * @param queueSize          Maximum idle runtimes
     * @param queueUpThreshold   How eager the pool is to increase the maximum idle runtimes
     * @param queueDownThreshold How eager the pool is to decrease the currently active runtimes
     * @param newThreshold       How eager the pool is to increase the currently active runtimes
     */
    public void runtimePoolStartEvent(
            String appName,
            int hardMinimum,
            int hardMaximum,
            int activeRuntimes,
            int queueSize,
            int queueUpThreshold,
            int queueDownThreshold,
            int newThreshold
    );

    /**
     * Runtime pool update event.
     *
     * @param activeRuntimes     Currently active runtimes
     * @param queueSize          Maximum idle runtimes
     * @param queueUpThreshold   How eager the pool is to increase the maximum idle runtimes
     * @param queueDownThreshold How eager the pool is to decrease the currently active runtimes
     * @param newThreshold       How eager the pool is to increase the currently active runtimes
     */
    public void runtimePoolUpdateEvent(
            String appName,
            int activeRuntimes,
            int queueSize,
            int queueUpThreshold,
            int queueDownThreshold,
            int newThreshold
    );

    /**
     * Monitoring event at the start of request processing
     *
     */
    public void requestStartEvent(
            GrizzlyRequest request,
            GrizzlyResponse response
    );

    /**
     * Monitoring event at the end of request processing
     *
     */
    public void requestEndEvent(
            GrizzlyRequest request,
            GrizzlyResponse response
    );
}
